@@ -3,11 +3,13 @@
  *   See README file for details.
  */
 
+/* All included by local.h
 #include "S.h"
 #undef WARN
 #undef ERROR
 
 #include <Rinternals.h>
+*/
 
 #include "local.h"
 extern int deitype(char *);  /* in lfstr.c */
@@ -125,14 +127,20 @@ static void basis(double *x, double *t, double *f, int dim, int p)
 }
 #endif
 
+#include "Rversion.h"
+
 static void 
 vbasis(double **x, double *t, int n, int d, int *ind, int m, int p, double *X)
 {
     SEXP call, pcall, s;
 
     /* two integer args, then 1+d double args */
+#if R_VERSION >= R_Version(4, 5, 0)
+    PROTECT(pcall = call = allocLang(d + 5));
+#else
     PROTECT(pcall = call = allocList(d + 5));
     SET_TYPEOF(call, LANGSXP);
+#endif
     SETCAR(pcall, (SEXP) bsf2);
     pcall = CDR(pcall);
     SETCAR(pcall, ScalarInteger(d));
@@ -236,11 +244,11 @@ Sint *mi;
 }
 
 static void slocfit(x,y,c,w,b,lim,mi,dp,str,sca,xev,wdes,wtre,wpc,nvc,
-  iwk1, iwk2,lw,mg,L,kap,dv,nd,sty,bs)
+  iwk1, iwk2,lw,mg,L,kap,dv,nd,sty) /* ,bs) */
 double *x, *y, *c, *w, *b, *lim, *dp, *sca, *xev, *L, *kap, *wdes, *wtre, *wpc;
 Sint *mi, *nvc, *iwk1, *iwk2, *lw, *mg, *dv, *nd, *sty;
 char **str;
-CALL_S_FUNC *bs;
+/* CALL_S_FUNC *bs; */
 { Sint n, d, i;
 
   mi[MKER] = lfkernel(str[0]);
@@ -250,10 +258,10 @@ CALL_S_FUNC *bs;
   mi[MACRI]= lfacri(str[4]);
   mi[MKT]  = lfketype(str[5]);
 
-  if (mi[MUBAS])
+/*  if (mi[MUBAS])
   { bsfunc = bs[0];
     bsf2 = bs[1];
-  }
+  } */
   lf_error = 0;
   n = mi[MN]; d = mi[MDIM];
 
@@ -442,14 +450,13 @@ double *x, *y, *w, *c, *ba, *fit, *xev, *coef, *sv, *wpc, *sca, *dp;
 Sint *cv, *st, *cell, *nvc, *mi, *mg, *dv, *nd, *sty;
 char **what;
 void **bs;
-{ Sint i, n;
+{ Sint i;
 
   recoef(xev,coef,cell,nvc,mi,dp);
   setsmpar(&lf.sp,dp,mi);
   setevs(&lf.evs,mi,dp[DCUT],mg,NULL);
 
   if (mi[MUBAS]) bsfunc = bs[0];
-  n = mi[MN];
   lf_error = 0;
   lf.evs.ncm = nvc[1]; lf.evs.nce = nvc[4];
 
@@ -604,7 +611,7 @@ void slscv(double *x, int *n, double *h, double *z);
 
 static const R_CMethodDef CEntries[]  = {
     {"guessnv", (DL_FUNC) &guessnv, 6},
-    {"slocfit", (DL_FUNC) &slocfit, 25},
+    {"slocfit", (DL_FUNC) &slocfit, 24},
     {"sfitted", (DL_FUNC) &sfitted, 23},
     {"spreplot", (DL_FUNC) &spreplot, 20},
     {"triterm", (DL_FUNC) &triterm, 12},
